summaryrefslogtreecommitdiff
path: root/lib/plugins/popularity/helper.php
diff options
context:
space:
mode:
authorGuillaume Turri <guillaume.turri@gmail.com>2010-12-18 10:27:49 +0100
committerAndreas Gohr <andi@splitbrain.org>2010-12-18 10:38:32 +0100
commit5827ba0b8aa706e4201a3dc654b3c2cf141f6dd2 (patch)
treecc5046f96c40e495b4434401a117e80f995424b4 /lib/plugins/popularity/helper.php
parent02700828f76adcfc63a9dafe75ffa941cdb9831b (diff)
downloadrpg-5827ba0b8aa706e4201a3dc654b3c2cf141f6dd2.tar.gz
rpg-5827ba0b8aa706e4201a3dc654b3c2cf141f6dd2.tar.bz2
Popularity plugin displays the last time the data was sent
Diffstat (limited to 'lib/plugins/popularity/helper.php')
-rw-r--r--lib/plugins/popularity/helper.php27
1 files changed, 26 insertions, 1 deletions
diff --git a/lib/plugins/popularity/helper.php b/lib/plugins/popularity/helper.php
index 00a359cbd..629d0bd67 100644
--- a/lib/plugins/popularity/helper.php
+++ b/lib/plugins/popularity/helper.php
@@ -13,7 +13,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin {
/**
* Name of the file which determine if the the autosubmit is enabled,
* and when it was submited for the las time
*/
var $autosubmitFile;
@@ -22,10 +22,19 @@ class helper_plugin_popularity extends Dokuwiki_Plugin {
*/
var $autosubmitErrorFile;
+ /**
+ * Name of the file which determine when the popularity data was manually
+ * submitted for the last time
+ * (If this file doesn't exist, the data has never been sent)
+ */
+ var $popularityLastSubmitFile;
+
+
function helper_plugin_popularity(){
global $conf;
$this->autosubmitFile = $conf['cachedir'].'/autosubmit.txt';
$this->autosubmitErrorFile = $conf['cachedir'].'/autosubmitError.txt';
+ $this->popularityLastSubmitFile = $conf['cachedir'].'/lastSubmitTime.txt';
}
function getMethods(){
@@ -48,6 +57,12 @@ class helper_plugin_popularity extends Dokuwiki_Plugin {
'params' => array(),
'return' => array('data' => 'string')
);
+ $result[] = array(
+ 'name' => 'lastSentTime',
+ 'desc' => 'Compute the last time popularity data was sent',
+ 'params' => 'array()',
+ 'return' => array('data' => 'int')
+ );
return $result;
}
@@ -76,6 +91,16 @@ class helper_plugin_popularity extends Dokuwiki_Plugin {
}
/**
+ * Compute the last time the data was sent. If it has never been sent, we return 0.
+ */
+ function lastSentTime(){
+ $manualSubmission = @filemtime($this->popularityLastSubmitFile);
+ $autoSubmission = @filemtime($this->autosubmitFile);
+
+ return max((int) $manualSubmission, (int) $autoSubmission);
+ }
+
+ /**
* Gather all information
* @return The popularity data as a string
*/
@@ -13,7 +13,7 @@ class helper_plugin_popularity extends Dokuwiki_Plugin {
/**
* Name of the file which determine if the the autosubmit is enabled,
- * and when it was submited for the las time
+ * and when it was submited for the last time
*/
var $autosubmitFile;